@@ -65,6 +65,12 @@ def gauss_1d(sigma=1., dt=1., limit=.01, normalize=True):
 def triangle(dt=.1, normalize=True):
     """
     Make a ramp from 0 to 1 back to 0 again by dt.
+    
+    :param dt: timestep interval. Kernel will be of length 2/dt - 1 with
+        peak at 1/dt.
+    
+    :param normalize: If True, the kernel sums to 1. Otherwise, each point
+        on the ramp is quantized by an integer.
     """
     k = numpy.arange(dt, 1, dt)
     k = numpy.concatenate((k, numpy.arange(1, 0, -dt)))
@@ -73,4 +79,27 @@ def triangle(dt=.1, normalize=True):
     if normalize:
         k = numpy.divide(k,numpy.sum(k)/dt)
     
+    return k
+    
+def rectangle_window(window=0, dt=.1, normalize=True):
+    """
+    Make a rectangle (really a vector) that has a particular length.
+    
+    :param window: Length of the kernel, in ms. A value of zero (default), will
+        still make a kernel of len == 1, corresponding to 1 time interval value,
+        and filtering with such a kernel will yield the input.
+        
+    .. Note:: A time window of 5 ms, say, will be different depending on the value
+        of dt. If dt == 1, then the kernel will range from [-2,2] across 5 values.
+        If dt == 0.1, then the kernel will range from [-2.5, 2.5] across 51 values.
+    """
+    the_len = int(window/dt)
+    if the_len % 2 != 1:
+        the_len += 1 # Make sure odd
+    k = numpy.ones(the_len)
+    
+    # Normalize
+    if normalize:
+        k = numpy.divide(k,float(the_len))
+    
     return k
\ No newline at end of file
